POLYAXON_KEYS_HEADER = "POLYAXON_HEADER"
POLYAXON_KEYS_HEADER_SERVICE = "POLYAXON_HEADER_SERVICE"
POLYAXON_KEYS_AUTHENTICATION_TYPE = "POLYAXON_AUTHENTICATION_TYPE"
POLYAXON_KEYS_LOG_LEVEL = "POLYAXON_LOG_LEVEL"
POLYAXON_KEYS_K8S_NAMESPACE = "POLYAXON_K8S_NAMESPACE"
POLYAXON_KEYS_API_HOST = "POLYAXON_API_HOST"
POLYAXON_KEYS_API_PORT = "POLYAXON_API_PORT"
POLYAXON_KEYS_API_VERSION = "POLYAXON_API_VERSION"
POLYAXON_KEYS_USE_HTTPS = "POLYAXON_USE_HTTPS"
POLYAXON_KEYS_VERIFY_SSL = "POLYAXON_VERIFY_SSL"
POLYAXON_KEYS_IN_CLUSTER = "POLYAXON_IN_CLUSTER"
POLYAXON_KEYS_IS_MANAGED = "POLYAXON_IS_MANAGED"
POLYAXON_KEYS_IS_LOCAL = "POLYAXON_IS_LOCAL"
POLYAXON_KEYS_IS_OFFLINE = "POLYAXON_IS_OFFLINE"
POLYAXON_KEYS_SECRET_KEY = "POLYAXON_SECRET_KEY"
POLYAXON_KEYS_SECRET_INTERNAL_TOKEN = "POLYAXON_SECRET_INTERNAL_TOKEN"
POLYAXON_KEYS_SECRET_EPHEMERAL_TOKEN = "POLYAXON_SECRET_EPHEMERAL_TOKEN"
POLYAXON_KEYS_SECRET_USER_TOKEN = "POLYAXON_SECRET_USER_TOKEN"
POLYAXON_KEYS_JOB_INFO = "POLYAXON_JOB_INFO"
POLYAXON_KEYS_ARTIFACTS_PATHS = "POLYAXON_ARTIFACTS_PATHS"
POLYAXON_KEYS_OUTPUTS_PATH = "POLYAXON_OUTPUTS_PATH"
POLYAXON_KEYS_LOGS_PATH = "POLYAXON_LOGS_PATH"
POLYAXON_KEYS_PARAMS = "POLYAXON_PARAMS"
POLYAXON_KEYS_CONTAINER_ID = "POLYAXON_CONTAINER_ID"
POLYAXON_KEYS_HEALTH_CHECK_URL = "POLYAXON_HEALTH_CHECK_URL"
POLYAXON_KEYS_RECONCILE_URL = "POLYAXON_RECONCILE_URL"
POLYAXON_KEYS_NO_OP = "POLYAXON_NO_OP"
POLYAXON_KEYS_HASH_LENGTH = "POLYAXON_HASH_LENGTH"
